@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.5.0-7
+# Application Name - Health Check V0.5.0-8
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -170,7 +170,7 @@ class Ui_MainWindow(object):
         font.setPointSize(18)
         #Accelorator information
         self.lbl_Accel_Info = QtGui.QLabel(self.tab)
-        self.lbl_Accel_Info.setGeometry(QtCore.QRect(200, 30, 400, 20))
+        self.lbl_Accel_Info.setGeometry(QtCore.QRect(200, 30, 400, 21))
         self.lbl_Accel_Info.setFont(font)
         self.lbl_Accel_Info.setObjectName("lbl_Accel_Info")
 
@@ -233,14 +233,14 @@ class Ui_MainWindow(object):
 
         # Set up the GPS Info label
         self.lbl_GpsPos = QtGui.QLabel(self.tab_2)
-        self.lbl_GpsPos.setGeometry(QtCore.QRect(10, 60, 190, 20))
+        self.lbl_GpsPos.setGeometry(QtCore.QRect(10, 60, 190, 21))
         self.lbl_GpsPos.setFont(font)
         self.lbl_GpsPos.setObjectName("lbl_GpsPos")
         self.lbl_GpsPos.setText("GPS Position")
         
         # GPS Info Field
         self.lbl_Gps_Info = QtGui.QLabel(self.tab_2)
-        self.lbl_Gps_Info.setGeometry(QtCore.QRect(220, 60, 381, 20))
+        self.lbl_Gps_Info.setGeometry(QtCore.QRect(220, 60, 420, 21))
         self.lbl_Gps_Info.setObjectName("lbl_Gps_Info")
         self.lbl_Gps_Info.setFont(font)
 
@@ -349,7 +349,13 @@ class Ui_MainWindow(object):
         self.tab_4 = QtGui.QWidget()
         self.tab_4.setObjectName("tab_4")
 
-
+        # Setup and draw the button
+        self.pushButton_reboot = QtGui.QPushButton(self.tab_4)
+        self.pushButton_reboot.setGeometry(QtCore.QRect(10, 10, 371, 41))
+        self.pushButton_reboot.setObjectName("pushButton_reboot")
+        self.pushButton_reboot.setText("System Reboot")
+        # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
+        QtCore.QObject.connect(self.pushButton_reboot, QtCore.SIGNAL('clicked()'), self.reboot_sys)
 
     
         self.tabWidget.addTab(self.tab_4, "")
@@ -363,7 +369,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.5.0-7 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.5.0-8 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -416,6 +422,15 @@ class Ui_MainWindow(object):
         self.lbl_Gps_Info.setText(var_g_GPS)
 
 
+    def reboot_sys(self):
+       
+        # Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
+        b = None
+        # X-term - grab 10 buffered front camera images, and throw them into an image file.
+        # Everyone recommends 1.... but 10 gave more light! - so i used it :D
+        b = os.popen('sudo /sbin/reboot')
+        b.close ()
+        
 # Funtion - update the front camera image
     def updateImage(self):
        
@@ -441,8 +456,13 @@ class Ui_MainWindow(object):
         g.lstrip()
         g.rstrip()
 
+
         if g.strip() == "3.2010.02-8":
             self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1.1")
+        elif g.strip() == "3.2010.02-8.002":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1.1")
+        elif g.strip() == "3.2010.02-8.001":
+            self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1.1")
         elif g.strip() == "2.2009.51-1":
             self.lbl_Maemo_Ver_Info.setText(g.strip() + " - Pr 1.1")
         elif g.strip() == "2009.51-1.203.2":
@@ -591,7 +611,7 @@ class Ui_MainWindow(object):
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.0-7", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.0-8", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
